@@ -5,7 +5,8 @@
 #'
 #' @param arg A function argument to be checked
 #' @param required_vars A list of variables created using `exprs()`
-#' @param check_is_grouped Throws an error if `dataset` is grouped?
+#' @param check_is_grouped Throws an error if `dataset` is grouped
+#' @param check_is_rowwise Throws an error if `dataset` is rowwise
 #' @param optional Is the checked argument optional? If set to `FALSE` and `arg`
 #' is `NULL` then an error is thrown
 #'
@@ -44,6 +45,7 @@
 assert_data_frame <- function(arg,
                               required_vars = NULL,
                               check_is_grouped = TRUE,
+                              check_is_rowwise = TRUE,
                               optional = FALSE,
                               arg_name = rlang::caller_arg(arg),
                               message = NULL,
@@ -70,7 +72,16 @@ assert_data_frame <- function(arg,
   if (check_is_grouped && dplyr::is_grouped_df(arg)) {
     cli_abort(
       message = message %||%
-        "Argument {.arg {arg_name}} must not be a grouped dataset, please `ungroup()` it.",
+        "Argument {.arg {arg_name}} must not be a grouped dataset, please `dplyr::ungroup()` it.",
+      class = c(class, "assert-admiraldev"),
+      call = call
+    )
+  }
+
+  if (check_is_rowwise && inherits(arg, "rowwise_df")) {
+    cli_abort(
+      message = message %||%
+        "Argument {.arg {arg_name}} must not be a rowwise dataset, please `dplyr::ungroup()` it.",
       class = c(class, "assert-admiraldev"),
       call = call
     )
@@ -272,7 +283,7 @@ assert_character_vector <- function(arg, values = NULL, named = FALSE,
 
   message <-
     message %||%
-    ifelse(
+    if_else(
       is.null(values),
       "Argument {.arg {arg_name}} must be {.cls character}, but is {.obj_type_friendly {arg}}.",
       "Argument {.arg {arg_name}} must be {.cls character} with values {.val {values}}."
@@ -412,7 +423,7 @@ assert_symbol <- function(arg,
   # set default error message, if not specified
   message <-
     message %||%
-    ifelse(
+    if_else(
       is_missing(arg),
       "Argument {.arg {arg_name}} must be a {.cls symbol}, but is missing.",
       "Argument {.arg {arg_name}} must be a {.cls symbol}, but is {.obj_type_friendly {arg}}."
@@ -1470,7 +1481,7 @@ assert_varval_list <- function(arg, # nolint
 #' example_fun(exprs(DTHDOM = "AE", DTHSEQ = AESEQ))
 #'
 #' try(example_fun(exprs("AE", DTSEQ = AESEQ, !!list("a"), !!list("a"))))
-assert_expr_list <- function(arg, # nolint
+assert_expr_list <- function(arg,
                              required_elements = NULL,
                              named = FALSE,
                              optional = FALSE,
@@ -1981,3 +1992,4 @@ assert_same_type <- function(...,
 
   invisible()
 }
+# lintr: enable_linter undesirable_function_linter
