@@ -1,10 +1,10 @@
 # arg_name ----
-## Test 1: arg_name works ----
-test_that("arg_name Test 1: arg_name works", {
-  withr::local_options(lifecycle_verbosity = "quiet")
-  expect_equal(arg_name(sym("a")), "a")
-  expect_equal(arg_name(call("enquo", sym("a"))), "a")
-  expect_error(arg_name("a"), "Could not extract argument name from")
+## Test 1: deprecation error if function is called ----
+test_that("arg_name Test 1: deprecation error if function is called", {
+  expect_error(
+    arg_name(sym("a")),
+    class = "lifecycle_error_deprecated"
+  )
 })
 
 # convert_dtm_to_dtc ----
@@ -18,10 +18,9 @@ test_that("convert_dtm_to_dtc Test 2: works if dtm is in correct format", {
 
 ## Test 3: Error is thrown if dtm is not in correct format ----
 test_that("convert_dtm_to_dtc Test 3: Error is thrown if dtm is not in correct format", {
-  expect_error(
+  expect_snapshot(
     convert_dtm_to_dtc("2022-04-05T15:26:14"),
-    "lubridate::is.instant(dtm) is not TRUE",
-    fixed = TRUE
+    error = TRUE
   )
 })
 
@@ -103,3 +102,48 @@ test_that("extract_vars Test 11: works with calls", {
     expected = unname(exprs(BASE, AVAL, LLQ))
   )
 })
+
+# %or% ----
+## Test 12: %or% works ----
+test_that("extract_vars Test 12: %or% works", {
+  input <- dplyr::tribble(
+    ~USUBJID, ~AVAL,
+    "P01",    2,
+  )
+  expect_equal(
+    input,
+    expected = input %>%
+      dplyr::select(-AVAL) %>%
+      dplyr::mutate(AVAL = sqrt("4") %or% 2)
+  )
+})
+
+## Test 13: %or% deprecation message if function is called ----
+test_that("extract_vars Test 13: %or% deprecation message if function is called", {
+  expect_snapshot({
+    input <- dplyr::tribble(
+      ~USUBJID, ~AVAL,
+      "P01",    2,
+    )
+    result <- input %>%
+      dplyr::select(-AVAL) %>%
+      dplyr::mutate(AVAL = sqrt("4") %or% 2)
+  })
+})
+
+# valid_time_units ----
+## Test 14: works as intended ----
+test_that("valid_time_units Test 14: works as intended", {
+  expect_equal(
+    valid_time_units(),
+    c("years", "months", "days", "hours", "minutes", "seconds")
+  )
+})
+
+
+## Test 15: deprecation message if function is called ----
+test_that("valid_time_units Test 15: deprecation message if function is called", {
+  expect_snapshot({
+    result <- valid_time_units()
+  })
+})
