@@ -1,10 +1,10 @@
 # enumerate ----
-## Test 1: enumerate works ----
-test_that("enumerate Test 1: enumerate works", {
-  withr::local_options(lifecycle_verbosity = "quiet")
-  expect_equal(enumerate(letters[1]), "`a`")
-  expect_equal(enumerate(letters[1:3]), "`a`, `b` and `c`")
-  expect_equal(enumerate(1:3, quote_fun = NULL), "1, 2 and 3")
+## Test 1: deprecation error if function is called ----
+test_that("enumerate Test 1: deprecation error if function is called", {
+  expect_error(
+    enumerate(letters[1]),
+    class = "lifecycle_error_deprecated"
+  )
 })
 
 # squote ----
